@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from BeautifulSoup import Comment
 from parser import HtmlMinifyParser
-from util import force_decode
+from util import force_decode, between_two_tags
 
 EXCLUDE_TAGS = ('pre', 'script', 'textarea',)
 
@@ -31,6 +31,11 @@ def html_minify(html_code, ignore_comments=True):
 
     for index, line in enumerate(lines):
         minified_line = line.strip()
+
+        # not in between two tags
+        if not between_two_tags(minified_line, minified_lines, index):
+            minified_line = ' %s' % minified_line
+
         minified_lines.append(str(minified_line))
 
     content = "".join(minified_lines)
